/*********************************************************************

 Author        : ADI - Apps            www.analog.com/MicroConverter

 Date          : May. 07

 File          : PowerDown.c

 Hardware      : ADuC7026

 Description   : The part is powered down by writing 0x40 to the POWCON 
 				 register. The part is then inactive until XIRQ is pressed. 
				 This causes an interrupt to occur. Once the interupt 
				 routine has been executed, the part reamins powered on and 
				 runs as normal.	

				 Note: P1.4 must be tied to ground to prevent it causing a 
				 	   continuous interupt.	
		
*********************************************************************/

#include <ADuC7026.h>					// 	Include ADuC7026 Header File


void delay(int);
										// 	Memory function macro 
int main (void)  {
int it1,it2;
	delay(1000);
	IRQEN = XIRQ0_BIT;					//	Enable XIRQ0 in IRQEnable 
   	GP0DAT = 0x80000000;				//	Configure port 0.7 as output 
	POWKEY1 = 0x01;
	POWCON |= 0x40;	   					// Stop mode 
	POWKEY2 = 0xF4;
		
	it1 = it1 * it2; //Dummy instruction
	while(1)
	{
		GP0DAT ^= 0x00ff0000;	   		// 	Complement Port 2
		delay(1000);					//	Delay to make blink visible
	}
                  
}

void IRQ_Handler() __irq
{
	while(1)
	{
		GP0DAT ^= 0x00ff0000;	   		// 	Complement Port 2
		delay(1000);					//	Delay to make blink visible
	}
}



void delay (int length)
{
	while (length >=0)
    	length--;
}



 
